/***********************************************************************
 * pc0_summer.
 ***********************************************************************
 * Schaltet den PC[0,1,2] auf Ausgang/High.
 * Schaltung: myAVR Board MK1 LPT
 ***********************************************************************
 * Prozessor: ATmega8L
 * Fuse: Low 0xFF, High 0xD9
 * Programmer: sp12
 * Takt: 3686400 Hz (Ext. Crystal/Resonator High Freq.; Start-up time:
 *                   16K CK + 64 ms; [CKSEL=1111 SUT=11])
 * Sprache: ANSI C
 * Datum: $Date$
 * Version: $Revision$
 * Autor: $Author$
 ***********************************************************************
 * PINBELEGUNG
 * +----+-----+-------------+------------------------------------------+
 * |  # | Pin | Standard    | Notiz                                    |
 * +----+-----+-------------+------------------------------------------+
 * | 01 |  C6 | RESET       |                                          |
 * | 02 |  D0 | RXD         |                                          |
 * | 03 |  D1 | TXD         |                                          |
 * | 04 |  D2 | INT0        |                                          |
 * | 05 |  D3 | INT1        |                                          |
 * | 06 |  D4 | XCK/T0      |                                          |
 * | 07 |     | VCC         |                                          |
 * | 08 |     | GND         |                                          |
 * | 09 |  B6 | XTAL1/TOSC1 |                                          |
 * | 10 |  B7 | XTAL2/TOSC2 |                                          |
 * | 11 |  D5 | T1          |                                          |
 * | 12 |  D6 | AIN0        |                                          |
 * | 13 |  D7 | AIN1        |                                          |
 * | 14 |  B0 | ICP1        |                                          |
 * | 15 |  B1 | OC1A        |                                          |
 * | 16 |  B2 | SS/OC1B     |                                          |
 * | 17 |  B3 | MOSI/OC2    |                                          |
 * | 18 |  B4 | MISO        |                                          |
 * | 19 |  B5 | SCK         |                                          |
 * | 20 |     | AVCC        |                                          |
 * | 21 |     | AREF        |                                          |
 * | 22 |     | GND         |                                          |
 * | 23 |  C0 | ADC0        | Summer                                   |
 * | 24 |  C1 | ADC1        |                                          |
 * | 25 |  C2 | ADC2        |                                          |
 * | 26 |  C3 | ADC3        |                                          |
 * | 27 |  C4 | ADC4/SCL    |                                          |
 * | 28 |  C5 | ADC5/SDA    |                                          |
 * +----+-----+-------------+-------------------------------------------
 **********************************************************************/

/* Benötigte Bibliotheken */
#include <avr/io.h>
#include <avr/sleep.h>
#include <avr/interrupt.h>
/* #include "../myAVR_Board_MK1_LPT.h" */

/* Prototypen */
int main(void);
void hw_init(void);
void t2_init(void);

/***********************************************************************
 * main
 ***********************************************************************
 * Hier fängt das Programm an zu arbeiten.
 **********************************************************************/
int main(void)
{
	cli(); /* Alle Interrupts ausschalten */
	hw_init(); /* Hardware initialisieren */
	sei(); /* Interrupts wieder einschalten */
	
	/* ms Timer 2 starten */
	t2_init();
	
	while(1);
	
	/* Programmende */
	return 0;
}

/***********************************************************************
 * hw_init
 ***********************************************************************
 * Initialisierung der Hardware.
 **********************************************************************/
void hw_init(void)
{
	/* Ein(0)-/Ausgabe(1) Pins festlegen */
	DDRD = 0b00000000;
	DDRB = 0b00000000;
	DDRC = 0b00000001;
	
	/* Zustand bei Ausgängen bzw. PullUp(1) bei Eingängen festlegen */
	PORTD = 0b00000000;
	PORTB = 0b00000000;
	PORTC = 0b00000000;
	
	/* Standardmäßigen Prozessor Schlafmodus wählen */
	set_sleep_mode(SLEEP_MODE_STANDBY); /* PWR-Down, Ext.Crystal-Up */
}

/***********************************************************************
 * t2_init
 ***********************************************************************
 * Initialisierung von Timer 2. Dieser Timer tickt alle ms.
 * Abweichung pro ms: +0,117647058823529411764705882353 µs. 
 **********************************************************************/
void t2_init(void)
{
	/* Timer2 im CTC-Mode mit clkT2S/1024 (From prescaler) */
	TCCR2 = ( _BV(WGM21) | _BV(CS20) | _BV(CS21) | _BV(CS22) );
	OCR2 = 14; /* Zähle bis 14 */
	/* löse SIG_SIG_OVERFLOW2 aus, wenn 14 erreicht ist */
	TIMSK |= _BV(TOIE2);
}

/***********************************************************************
 * Interrupt Timer 2 Compare Match
 **********************************************************************/
SIGNAL(SIG_SIG_OVERFLOW2)
{
	PORTC |= _BV(PC0); /* schalte Summer ein */
	/* PORTC &= ~_BV(PC0); */ /* schalte Summer aus */
}
